# SPACEHANDLER.VIEW3D.EVENT

# Hotspots Space Handler Script v0.8
# (c) 2005 Mariano Hidalgo a.k.a uselessdreamer 
# released under Blender Artistic License

import Blender
from Blender import Camera, Object, Scene, Draw, Lamp, Window

evt = Blender.event
if evt == Draw.LEFTMOUSE:
	
	# CameraSwitcher Preferences
	autoswitch = 1 # Go to camera view after switching?
	showlamps = 1  # Do spotlights show up on the list?
	
	# Progressive Renderer Preferences
	firstPassPercent = 16
	secondPassPercent = 8
	thirdPassPercent = 2	
	backToWindowAfter = 1 # If you always render in 3D View change this to 0
	
		
	
	# Gather info about which 3D Window is generating the event
	# Grab its size and location on the screen
	click = Window.GetMouseCoords()
	winId = Window.GetAreaID()
	winSize = Window.GetAreaSize()
	winData = Window.GetScreenInfo()
	
	width = winSize[0]
	height = winSize[1]
	for win in winData:
		if win["id"] == winId:
			xmin = win["vertices"][0]
			ymin = win["vertices"][1]
			xmax = win["vertices"][2]
			ymax = win["vertices"][3]
	
		
	#
	# This deals with the Camera Hotspot Menu
	#
	
	if click[0] >(xmin +5) and click[0] < (xmin + 25) and click[1] > (ymin -5) and click[1] < (ymax- (height - 30)):
		scn = Scene.GetCurrent()
		objs = Object.Get()
		currcam = scn.getCurrentCamera().getName()
		maincams = []
		auxcams = ["%l"]
		lightcams = ["%l"]
		menutext = "Switch Camera%t"
		
		for cam in objs:
			if cam.getType() == 'Camera':
				if cam.getName() != "Main Camera" and cam.getName() != "Aux Camera":
					auxcams.append(cam.getName())
				else:
					maincams.append(cam.getName())	
			if cam.getType() == "Lamp" and showlamps == 1 and Lamp.Get(cam.getData().getName()).getType() == 2:
					lightcams.append(cam.getName())	
		
		maincams.reverse()
		maincams.extend(auxcams)
		maincams.extend(lightcams)
		
		for cam in maincams:
				menutext = menutext + "| "
				if cam == currcam:
					menutext = menutext + "> "
				else:
					menutext = menutext + "   "
				menutext = menutext  + cam 
				
		menutext = menutext + " | %l | Add New Camera | Go to Camera View                   NumPad 0| Align Camera to View    Ctrl Alt NumPad 0"
		whichcam = Draw.PupMenu(menutext)
		if whichcam != -1 and whichcam < (len(maincams)+1):
			scn.setCurrentCamera(Object.Get(maincams[whichcam-1]))
			Window.CameraView(0)
			Window.Redraw()	
		else:
			if whichcam == (len(maincams) +2):
				c = Camera.New('persp')   
				c.lens = 35.0               
				scn = Scene.getCurrent()   
				ob = Object.New('Camera')  
				ob.link(c)                 
				scn.link(ob)               
				scn.setCurrentCamera(ob)
				Window.CameraView(1)   
			if whichcam == (len(maincams) +3):
				Window.CameraView(0)
				Window.Redraw()				   
			if whichcam == (len(maincams) +4):
				Window.CameraView(1)
		Blender.event = None 

	#
	# This deals with the Object Hotspot Menu
	#
	
	if click[0] >(xmin +30) and click[0] < (xmin + 150) and click[1] > (ymin -5) and click[1] < (ymax- (height - 30)):
		scn = Scene.getCurrent()
		objs = Object.Get()
		curOb = Object.GetSelected()
		filteredOb = []
		if len(curOb) > 0:
			obMenu = "Select " + curOb[0].getType() + " Object%t"
			for ob in objs:
				if ob.getType() == curOb[0].getType():
					obMenu = obMenu +"|"
					if ob == curOb[0]: obMenu = obMenu + "> "
					obMenu = obMenu + ob.getName()
					filteredOb.append(ob)
			obMenu = obMenu + "|%l|  Select all " +	curOb[0].getType()	
			obMenu = obMenu + "|  Delete selected"
			selOb = Draw.PupMenu(obMenu)
			if selOb != -1 and selOb <= len(filteredOb):
				for ob in objs:
					ob.select(0)
				obj = filteredOb[selOb-1]
				obj.select(1)
			if selOb == len(filteredOb)+2:
				for ob in filteredOb:
					ob.select(1)
			if selOb == len(filteredOb)+3:
				for ob in curOb:
					scn.unlink(ob)	

		Blender.event = None	
	
	#
	# This deals with the Progressive Render Hotspot
	#
	if click[0] > (xmin +(width -75)) and click[0] < (xmin + (width -30)) and click[1] > (ymin -5) and click[1] < (ymax- (height - 30)):
		scn=Scene.GetCurrent()
		context = scn.getRenderingContext()
		sizeX = context.imageSizeX()
		sizeY = context.imageSizeY()
		Scene.Render.EnableDispView()
		context.enableCropping(1)
		# First pass
		context.imageSizeX(sizeX / firstPassPercent)
		context.imageSizeY(sizeY / firstPassPercent)
		context.render()
		# Second pass
		context.imageSizeX(sizeX / secondPassPercent)
		context.imageSizeY(sizeY / secondPassPercent)
		context.render()
		# Third pass
		context.imageSizeX(sizeX / thirdPassPercent)
		context.imageSizeY(sizeY / thirdPassPercent)
		context.render()
		# Final pass
		context.imageSizeX(sizeX)
		context.imageSizeY(sizeY)
		doFinal = Draw.PupMenu("Render full resolution?%t | Yes | No")
		if doFinal == 1:
			context.render()
			Draw.PupMenu("Click to clear 3D View")
			
		if backToWindowAfter == 1: Scene.Render.EnableDispWin()
		
		Blender.event = None

	#
	# This deals with the Set Render Border Hotspot
	#
	if click[0] > (xmin +(width -95)) and click[0] < (xmin + (width -80)) and click[1] > (ymin +20) and click[1] < (ymax- (height - 30)):
		Window.SetKeyQualifiers(3)
		Window.QAdd(winId,Draw.BKEY,1)
		Window.QHandle(winId)
		Window.QRead()
		Blender.event = None
		Window.SetKeyQualifiers(0)
		Draw.Redraw()
	if click[0] > (xmin +(width -95)) and click[0] < (xmin + (width -80)) and click[1] > (ymin) and click[1] < (ymax- (height - 20)):
		scn = Scene.GetCurrent()
		context = scn.getRenderingContext()
		context.enableBorderRender(0)
		Blender.event = None
		Draw.Redraw()
		
	#
	# This deals with the Normal Render Hotspot
	#
	if click[0] > (xmin +(width -30)) and click[0] < (xmin + (width -5)) and click[1] > (ymin -5) and click[1] < (ymax- (height - 30)):
		
		scn=Scene.GetCurrent()
		context = scn.getRenderingContext()
		context.render()
		Blender.event = None
		
	#
	# This deals with the Animation Hotspot Menu
	#
	if click[0] > (xmin +(width -35)) and click[0] < (xmin + (width -5)) and click[1] > (ymax -30) and click[1] < (ymax- (5)):
		
		choi = Draw.PupMenu("Animation%t1|Play in Loop in 3D View|Play in Loop in All Windows| %l|Play Once in 3D View|Play Once in All Windows")
		if choi > 2: choi = choi -1
		#Draw.PupMenu(str(choi))	
		if choi != -1:
			scn = Scene.getCurrent()
			scn.play(choi-1)
		Blender.event = None
	
	#
	# This deals with the Python Scripts Hotspot
	#
	if click[0] > (xmin +5) and click[0] < (xmin + 50) and click[1] > (ymax -30) and click[1] < (ymax- (5)):
		if Window.EditMode():
			choi = Draw.PupMenu("Edit Mode Scripts%t1|Apply Deformation|Bevel Center|Clean mesh|Discombulator|Fix from Everything|Rvk1 to Rvk2|Bridge/Skin/Loft|Unweld|%l|Flatten|Remove Vertex Loop")		
			if choi == 1: Blender.Run(Blender.Get("scriptsdir") + "/" + "Apply_def.py")
			if choi == 2: Blender.Run(Blender.Get("scriptsdir") + "/" + "bevel_center.py")
			if choi == 3: Blender.Run(Blender.Get("scriptsdir") + "/" + "clean_mesh.py")
			if choi == 4: Blender.Run(Blender.Get("scriptsdir") + "/" + "discombulator.py")
			if choi == 5: Blender.Run(Blender.Get("scriptsdir") + "/" + "fixfromarmature.py")
			if choi == 6: Blender.Run(Blender.Get("scriptsdir") + "/" + "rvk1_torvk2.py")
			if choi == 7: Blender.Run(Blender.Get("scriptsdir") + "/" + "skin.py")
			if choi == 8: Blender.Run(Blender.Get("scriptsdir") + "/" + "unweld.py")
			if choi == 10: Blender.Run(Blender.Get("scriptsdir") +"/Scripts/" + "flatten.py")
			if choi == 11: Blender.Run(Blender.Get("scriptsdir") +"/Scripts/" + "remvrtloop03.py")
		else:	
			choi = Draw.PupMenu("Object Mode Scripts%t1|Axis Orientation Copy|Batch Object Name Editor|Make Instances")		
			if choi == 1: Blender.Run(Blender.Get("scriptsdir") +"/" + "Axiscopy.py")
			if choi == 2: Blender.Run(Blender.Get("scriptsdir") +"/" + "batch_name_edit.py")
			if choi == 3: Blender.Run(Blender.Get("scriptsdir") +"/" + "make_instances.py")
			
		Blender.event = None
		
	#
	# This deals with the Screens Hotspot Menu
	#
	if click[0] > (xmin +3) and click[0] < (xmin + 20) and click[1] > (ymax -(height /2)) and click[1] < (ymax- (height /4)):
		scrs= Window.GetScreens()
		scrmenu = "Change Screen%t"
		for scr in scrs:
			scrmenu = scrmenu + "|" + scr
		toscr = Draw.PupMenu(scrmenu)
		if toscr != -1: Window.SetScreen(scrs[toscr-1])

	#
	# This deals with the Selected Objects Hotspot
	#
	if click[0] >(xmin +500) and click[0] < (xmin + 600) and click[1] > (ymin -5) and click[1] < (ymax- (height - 30)):
		scn = Scene.getCurrent()
		objs = Object.GetSelected()
		objsnames = []
		for ob in objs:
			objsnames.append(ob.getName())
		
		objsnames.sort()
		menutext = str(len(objsnames)) + " objects selected:%t"
		for ob in objsnames:
			menutext = menutext + "|" 
			if ob == objs[0].getName():
				menutext = menutext + "> "
			else:
				menutext = menutext + "  "
			menutext = menutext + ob
		Draw.PupMenu(menutext)
		Blender.event = None
	
	#
	# This deals with the Mesh Edit Mode Tools Hotspots
	#
	
	if click[0] > (xmin +120) and click[0] < (xmin + 140) and click[1] > (ymax -30) and click[1] < (ymax- (5)):
		if Window.EditMode():
			Window.QAdd(winId,Draw.WKEY,1)
			Window.QHandle(winId)
			Blender.event = None
	if click[0] > (xmin +140) and click[0] < (xmin + 160) and click[1] > (ymax -30) and click[1] < (ymax- (5)):
		if Window.EditMode():
			Window.SetKeyQualifiers(48)
			Window.QAdd(winId,Draw.EKEY,1)
			Window.QHandle(winId)
			Blender.event = None
			Window.SetKeyQualifiers(0)
	if click[0] > (xmin +160) and click[0] < (xmin + 180) and click[1] > (ymax -30) and click[1] < (ymax- (5)):
		if Window.EditMode():
			Window.QAdd(winId,Draw.KKEY,1)
			Window.QHandle(winId)
			Blender.event = None			
	if click[0] > (xmin +200) and click[0] < (xmin + 220) and click[1] > (ymax -30) and click[1] < (ymax- (5)):
		if Window.EditMode():
			choice = Draw.PupMenu("Show/Hide Vertices%t|Hide Selected                    H|Hide Deselected      SHIFT H|Show Hidden               ALT H")
			if choice != -1:
				if choice == 2:	Window.SetKeyQualifiers(3)
				if choice == 3:	Window.SetKeyQualifiers(12)			
				Window.QAdd(winId,Draw.HKEY,1)
				Window.QHandle(winId)
				Blender.event = None
				Window.SetKeyQualifiers(0)
				Window.RedrawAll()
			Blender.event = None
	
	